import { ChangeDetectorRef, Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { MyPositionModel, PositionModel } from 'src/app/shared/model/position.model';
import { PositionService } from 'src/app/shared/services/position.service';

@Component({
  selector: 'app-position-unit',
  templateUrl: './position-unit.component.html',
  styleUrls: ['./position-unit.component.scss']
})
export class PositionUnitComponent implements OnInit {
  @Input() pathTitle = ['การจัดการข้อมูลองค์กร', 'ข้อมูลลักษณะงาน', 'กลุ่มพนักงาน']
  @Output() sendPathTitle: EventEmitter<string[]> = new EventEmitter<string[]>();
  activeTab: string = 'tab1'; // กำหนด tab เริ่มต้น

  // ฟังก์ชันในการเปลี่ยนแท็บ
  changeTab(tab: { id: string, text: string }) {
    this.sendPathTitle.emit(['การจัดการข้อมูลองค์กร', 'ข้อมูลลักษณะงาน', tab.text])
    this.activeTab = tab.id;
  }
  currentPage = 1
  selectedItems: string[] = [];
  page = Array.from({ length: 1 }, (_, i) => i + 1);
  positionList: PositionModel[] = []
  position: PositionModel = new MyPositionModel({})
  search = ""
  constructor(private positionService: PositionService,
    private toastr: ToastrService,
    private cdr: ChangeDetectorRef
  ) { }
  ngOnInit(): void {
    this.getPositionList()
  }
  getPositionList() {
    this.positionService.getList().subscribe(response => {
      this.positionList = response.map(x => new MyPositionModel(x))
      this.searchChange()
      this.cdr.detectChanges()
    })
  }
  searchChange() {
    this.currentPage = 1
    this.page = Array.from({ length: Math.ceil(this.positionListFilter().length / 10) }, (_, i) => i + 1);
  }
  positionListFilter() {
    return this.positionList.filter(x => x.positionId.includes(this.search) ||
      x.tdesc.includes(this.search) ||
      x.edesc.includes(this.search))
  }
  selectPosition(position?: PositionModel) {
    // this.showSuccess()
    this.position = new MyPositionModel(position || {})
  }

  showSuccess() {
    this.toastr.success('บันทึกข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  showSuccesssEdit() {
    this.toastr.success('เเก้ไขข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  showSuccessDelete() {
    this.toastr.success('ลบข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  addPosition() {
    this.positionService.post(this.position).subscribe((response: any) => {
      if (response.success) {
        this.getPositionList()
        this.showSuccess()
      }
    })
  }
  deletePosition() {
    this.positionService.delete(this.position).subscribe((response: any) => {
      if (response.success) {
        this.getPositionList()
        this.showSuccessDelete()
      }
    })
  }
  toggleSelection(positionId: string, event: Event) {
    const checked = (event.target as HTMLInputElement).checked;
    if (checked) {
      this.selectedItems.push(positionId);
    } else {
      this.selectedItems = this.selectedItems.filter(id => id !== positionId);
    }
  }
  toggleSelectAll(event: Event) {
    const checked = (event.target as HTMLInputElement).checked;
    if (checked) {
      this.selectedItems = this.positionListFilter().map(item => item.positionId);
    } else {
      this.selectedItems = [];
    }
  }
  deleteSelectedItems() {
    if (this.selectedItems.length === 0) {
      alert("เลือกข้อมูลก่อนลบ");
      return;
    }
  
    const selectedGroups = this.positionListFilter().filter(item => this.selectedItems.includes(item.positionId));
  
    this.positionService.delete(selectedGroups).subscribe({
      next: (response) => {
        console.log("ลบสำเร็จ", response);
        this.selectedItems = [];
        this.getPositionList();
        this.showSuccessDelete()
      },
      error: (error) => {
        console.error("เกิดข้อผิดพลาดในการลบ", error);
      }
    });
  }
}

